package cn.wise.sc.acquisition.business.service.impl;

import cn.wise.sc.acquisition.business.constant.Rcode;
import cn.wise.sc.acquisition.business.entity.TProcessesAuxiliary;
import cn.wise.sc.acquisition.business.enumation.ProjectEnum;
import cn.wise.sc.acquisition.business.mapper.TProcessesAuxiliaryMapper;
import cn.wise.sc.acquisition.business.model.query.TProcessesAuxiliaryQuery;
import cn.wise.sc.acquisition.business.service.ITProcessesAuxiliaryService;
import cn.wise.sc.acquisition.business.wrapper.page.Query;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author renchao
 * @since 2021-04-30
 */
@Service
@Slf4j
public class TProcessesAuxiliaryServiceImpl extends ServiceImpl<TProcessesAuxiliaryMapper, TProcessesAuxiliary> implements ITProcessesAuxiliaryService {

    @Override
    public R getPage(TProcessesAuxiliaryQuery tProcessesAuxiliaryQuery, Query query) {
        log.info(JSON.toJSONString(tProcessesAuxiliaryQuery));
        //参数校验
        //分页
        Page<TProcessesAuxiliary> page = new Page<>(query.getPageNum(), query.getPageSize());
        //条件封装
        QueryWrapper<TProcessesAuxiliary> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(tProcessesAuxiliaryQuery.getEquipmentID()),
                ProjectEnum.TProcessesAuxiliary.EQUIPMENT_ID.getLabel(),tProcessesAuxiliaryQuery.getEquipmentID());
        //查询
        Page<TProcessesAuxiliary> tSampleListPage = baseMapper.selectPage(page, queryWrapper);
        return R.ok(tSampleListPage);
    }

    @Override
    public R updateByUid(TProcessesAuxiliaryQuery query) {

        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //判断数据是否存在
        TProcessesAuxiliary temp = baseMapper.selectById(query.getUid());
        if (temp == null) {
            return R.failed("数据不存在，uid：" + query.getUid());
        }
        //条件封装
        TProcessesAuxiliary tSampleList = new TProcessesAuxiliary();
        BeanUtils.copyProperties(query, tSampleList);

        QueryWrapper<TProcessesAuxiliary> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ProjectEnum.TProcessesAuxiliary.UID.getLabel(), query.getUid());
        //修改
        int update = baseMapper.update(tSampleList, queryWrapper);
        if (update > 0) {
            return R.ok("修改成功");
        } else {
            log.info(JSON.toJSONString(tSampleList));
            return R.failed("修改失败");
        }

    }

    @Override
    public R insertTProcessesAuxiliary(TProcessesAuxiliaryQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        //uid自动生成 不能手动设置
        if (query.getUid() != null) {
            return R.failed("uid自动生成 不能手动设置");
        }
        //条件封装
        TProcessesAuxiliary tProcessesAuxiliary = new TProcessesAuxiliary();
        BeanUtils.copyProperties(query, tProcessesAuxiliary);
        //增加
        log.info(JSON.toJSONString(tProcessesAuxiliary));
        int insert = baseMapper.insert(tProcessesAuxiliary);
        if (insert > 0) {
            return R.ok("增加成功");
        } else {
            log.info(JSON.toJSONString(tProcessesAuxiliary));
            return R.failed("增加失败");
        }
    }
}
