package cn.wise.sc.acquisition.business.service.impl;

import cn.wise.sc.acquisition.business.constant.Rcode;
import cn.wise.sc.acquisition.business.entity.TProcessesBlast;
import cn.wise.sc.acquisition.business.enumation.ProjectEnum;
import cn.wise.sc.acquisition.business.mapper.TProcessesBlastMapper;
import cn.wise.sc.acquisition.business.model.query.TMineStopeQuery;
import cn.wise.sc.acquisition.business.model.query.TProcessesBlastQuery;
import cn.wise.sc.acquisition.business.model.vo.TProcessesBlastVo;
import cn.wise.sc.acquisition.business.service.ITMineStopeService;
import cn.wise.sc.acquisition.business.service.ITProcessesBlastService;
import cn.wise.sc.acquisition.business.util.BeanUtilsNewCopy;
import cn.wise.sc.acquisition.business.util.DateUtil;
import cn.wise.sc.acquisition.business.wrapper.page.Query;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 服务实现类  爆破工序
 * </p>
 *
 * @author renchao
 * @since 2021-04-29
 */
@Service
@Slf4j
public class TProcessesBlastServiceImpl extends ServiceImpl<TProcessesBlastMapper, TProcessesBlast> implements ITProcessesBlastService {

    @Autowired
    private ITMineStopeService itMineStopeService;

    @Override
    public R getPage(TProcessesBlastQuery tProcessesBlastQuery, Query query) {
        log.info(JSON.toJSONString(tProcessesBlastQuery));
        //参数校验
        //分页
        Page<TProcessesBlast> page = new Page<>(query.getPageNum(), query.getPageSize());
        //条件封装
        QueryWrapper<TProcessesBlast> queryWrapper = new QueryWrapper<>();
        //如果设计时间不为空 因为涉及到表连接，需要创建字段别名
        if (tProcessesBlastQuery.getBlastDate() != null) {
            StringBuilder stringBuilder = new StringBuilder();
            stringBuilder.append(ProjectEnum.TableAlias.A.getLabel()).append(ProjectEnum.TProcessesBlast.BLAST_DATE.getLabel());
            //前端传来的时间可能为2021-04-05 17:37:33.000, 需要查询 2021-04-05 00:00:00 到 2021-04-05 23:59:59 的数据 故作处理
            queryWrapper
                    .ge(stringBuilder.toString(), DateUtil.getBeginTimeStr(tProcessesBlastQuery.getBlastDate()))
                    .le(stringBuilder.toString(), DateUtil.getEndTimeStr(tProcessesBlastQuery.getBlastDate()));
        }
        //查询分页数据
        Page<TProcessesBlastVo> data = baseMapper.getPage(page, queryWrapper);
        return R.ok(data);
    }

    @Override
    public R updateByUid(TProcessesBlastQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //判断数据是否存在
        TProcessesBlast temp = baseMapper.selectById(query.getUid());
        if (temp == null) {
            return R.failed("数据不存在，uid：" + query.getUid());
        }
        //判断是否需要修改关联的 矿山爆区表
        if (StringUtils.isNotBlank(query.getStepName())
                || StringUtils.isNotBlank(query.getBlastAreaName())
                || StringUtils.isNotBlank(query.getStopeName())) {
            //判断矿山爆区表是否存在数据 不存在不能修改
            //query里不一定StopeName,StepName,BlastAreaName都有，需要从temp中拿query没有的，
            // 所以将query有的更新到temp中，再把temp中的复制到tMineStopeQuery
            BeanUtilsNewCopy.copyPropertiesIgnoreNull(query, temp);
            TMineStopeQuery tMineStopeQuery = new TMineStopeQuery();
            BeanUtils.copyProperties(temp, tMineStopeQuery);
            R volume = itMineStopeService.getByQuery(tMineStopeQuery);
            if (volume.getData() == null) {
                return R.failed("矿山爆区表数据不存在，StopeName,StepName,BlastAreaName");
            }
        }
        //条件封装
        TProcessesBlast tProcessesBlast = new TProcessesBlast();
        BeanUtils.copyProperties(query, tProcessesBlast);

        QueryWrapper<TProcessesBlast> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ProjectEnum.TProcessesBlast.UID.getLabel(), query.getUid());
        //修改
        int update = baseMapper.update(tProcessesBlast, queryWrapper);
        if (update > 0) {
            return R.ok("修改成功");
        } else {
            log.info(JSON.toJSONString(tProcessesBlast));
            return R.failed("修改失败");
        }
    }

    @Override
    public R insertTProcessesBlast(TProcessesBlastQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getStopeName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getStepName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getBlastAreaName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getHoleID());
        //uid自动生成 不能手动设置
        if (query.getUid() != null) {
            return R.failed("uid自动生成 不能手动设置");
        }
        //条件封装
        TProcessesBlast tProcessesDrilling = new TProcessesBlast();
        BeanUtils.copyProperties(query, tProcessesDrilling);
        //增加
        int insert = baseMapper.insert(tProcessesDrilling);
        if (insert > 0) {
            return R.ok("增加成功");
        } else {
            log.info(JSON.toJSONString(tProcessesDrilling));
            return R.failed("增加失败");
        }
    }

    @Override
    public R getByUid(TProcessesBlastQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //查询并且返回
        return R.ok(baseMapper.selectById(query.getUid()));
    }
}
