package cn.wise.sc.acquisition.business.service.impl;

import cn.wise.sc.acquisition.business.constant.Rcode;
import cn.wise.sc.acquisition.business.entity.TProcessesCrusher;
import cn.wise.sc.acquisition.business.enumation.ProjectEnum;
import cn.wise.sc.acquisition.business.mapper.TProcessesCrusherMapper;
import cn.wise.sc.acquisition.business.model.query.TProcessesCrusherQuery;
import cn.wise.sc.acquisition.business.model.vo.TProcessesCrusherVo;
import cn.wise.sc.acquisition.business.service.ITProcessesCrusherService;
import cn.wise.sc.acquisition.business.wrapper.page.Query;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author renchao
 * @since 2021-04-30
 */
@Service
@Slf4j
public class TProcessesCrusherServiceImpl extends ServiceImpl<TProcessesCrusherMapper, TProcessesCrusher> implements ITProcessesCrusherService {


    @Override
    public R getPage(TProcessesCrusherQuery tProcessesCrusherQuery, Query query) {
        log.info(JSON.toJSONString(tProcessesCrusherQuery));
        //参数校验
        //分页
        Page<TProcessesCrusher> page = new Page<>(query.getPageNum(), query.getPageSize());
        //条件封装
        QueryWrapper<TProcessesCrusher> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(tProcessesCrusherQuery.getEquipmentID()),
                ProjectEnum.TProcessesCrusher.EQUIPMENT_ID.getLabel(),tProcessesCrusherQuery.getEquipmentID());
        //查询
        Page<TProcessesCrusher> tSampleListPage = baseMapper.selectPage(page, queryWrapper);
        return R.ok(tSampleListPage);
    }

    @Override
    public R updateByUid(TProcessesCrusherQuery query) {

        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //判断数据是否存在
        TProcessesCrusher temp = baseMapper.selectById(query.getUid());
        if (temp == null) {
            return R.failed("数据不存在，uid：" + query.getUid());
        }
        //条件封装
        TProcessesCrusher tSampleList = new TProcessesCrusher();
        BeanUtils.copyProperties(query, tSampleList);

        QueryWrapper<TProcessesCrusher> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ProjectEnum.TProcessesCrusher.UID.getLabel(), query.getUid());
        //修改
        int update = baseMapper.update(tSampleList, queryWrapper);
        if (update > 0) {
            return R.ok("修改成功");
        } else {
            log.info(JSON.toJSONString(tSampleList));
            return R.failed("修改失败");
        }

    }

    @Override
    public R insertTProcessesCrusher(TProcessesCrusherQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        //uid自动生成 不能手动设置
        if (query.getUid() != null) {
            return R.failed("uid自动生成 不能手动设置");
        }
        //条件封装
        TProcessesCrusher tProcessesCrusher = new TProcessesCrusher();
        BeanUtils.copyProperties(query, tProcessesCrusher);
        //增加
        log.info(JSON.toJSONString(tProcessesCrusher));
        int insert = baseMapper.insert(tProcessesCrusher);
        if (insert > 0) {
            return R.ok("增加成功");
        } else {
            log.info(JSON.toJSONString(tProcessesCrusher));
            return R.failed("增加失败");
        }
    }
}
