package cn.wise.sc.acquisition.business.service.impl;

import cn.wise.sc.acquisition.business.constant.Rcode;
import cn.wise.sc.acquisition.business.entity.TProcessesBlastdesignHole;
import cn.wise.sc.acquisition.business.entity.TProcessesDrilling;
import cn.wise.sc.acquisition.business.enumation.ProjectEnum;
import cn.wise.sc.acquisition.business.mapper.TProcessesDrillingMapper;
import cn.wise.sc.acquisition.business.model.query.TMineStopeQuery;
import cn.wise.sc.acquisition.business.model.query.TProcessesBlastdesignHoleQuery;
import cn.wise.sc.acquisition.business.model.query.TProcessesDrillingQuery;
import cn.wise.sc.acquisition.business.model.vo.TProcessesDrillingVo;
import cn.wise.sc.acquisition.business.model.vo.TProcessesProductVo;
import cn.wise.sc.acquisition.business.service.ITMineStopeService;
import cn.wise.sc.acquisition.business.service.ITProcessesBlastdesignHoleService;
import cn.wise.sc.acquisition.business.service.ITProcessesDrillingService;
import cn.wise.sc.acquisition.business.util.BeanUtilsNewCopy;
import cn.wise.sc.acquisition.business.util.DateUtil;
import cn.wise.sc.acquisition.business.wrapper.page.Query;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * <p>
 * 服务实现类 穿孔工序
 * </p>
 *
 * @author renchao
 * @since 2021-04-29
 */
@Service
@Slf4j
public class TProcessesDrillingServiceImpl extends ServiceImpl<TProcessesDrillingMapper, TProcessesDrilling> implements ITProcessesDrillingService {


    @Autowired
    private ITMineStopeService itMineStopeService;

    @Autowired
    private ITProcessesBlastdesignHoleService itProcessesBlastdesignHoleService;

    @Override
    public R getPage(TProcessesDrillingQuery tProcessesDrillingQuery, Query query) {
        log.info(JSON.toJSONString(tProcessesDrillingQuery));
        //参数校验
        //分页
        Page<TProcessesDrilling> page = new Page<>(query.getPageNum(), query.getPageSize());
        //条件封装
        QueryWrapper<TProcessesDrilling> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(
                ProjectEnum.TProcessesDrilling.DEPTH.getLabel(),
                ProjectEnum.TProcessesDrilling.ROW_SPACE.getLabel(),
                ProjectEnum.TProcessesDrilling.HOLE_SPACE.getLabel(),
                ProjectEnum.TProcessesDrilling.STEP_HEIGHT.getLabel(),
                ProjectEnum.TProcessesDrilling.HOLE_BLAST_VOLUME.getLabel(),
                ProjectEnum.TProcessesDrilling.DESIGN_DEPTH.getLabel(),
                ProjectEnum.TProcessesDrilling.DESIGN_ROW_SPACE.getLabel(),
                ProjectEnum.TProcessesDrilling.DESIGN_HOLE_SPACE.getLabel()
        );
        //如果设计时间不为空 因为涉及到表连接，需要创建字段别名
        if (tProcessesDrillingQuery.getDrillingDate() != null) {
            //前端传来的时间可能为2021-04-05 17:37:33.000, 需要查询 2021-04-05 00:00:00 到 2021-04-05 23:59:59 的数据 故作处理
            queryWrapper
                    .ge(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getBeginTimeStr(tProcessesDrillingQuery.getDrillingDate()))
                    .le(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getEndTimeStr(tProcessesDrillingQuery.getDrillingDate()));
        }

        //查询分页数据
        Page<TProcessesDrillingVo> data = baseMapper.getPage(page, queryWrapper);
        StringBuffer depth = new StringBuffer()
                .append(ProjectEnum.TableAlias.A.getLabel())
                .append(ProjectEnum.TProcessesDrilling.DEPTH.getLabel());
        //查询，合计孔深
        Double depthSum = baseMapper.getSumByCondition(depth.toString(), queryWrapper);

        //查询，今日合计孔深
        //初始化QueryWrapper
        LocalDateTime now = LocalDateTime.now();
        queryWrapper = new QueryWrapper<>();
        queryWrapper
                .ge(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getBeginTimeStr(now))
                .le(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getEndTimeStr(now));

        Double todayDepthSum = baseMapper.getSumByCondition(depth.toString(), queryWrapper);


        //查询，本月合计孔深 上月26日到当前日期的实测孔深相加
        //初始化QueryWrapper
        queryWrapper = new QueryWrapper<>();
        queryWrapper
                .ge(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getBeginTimeStr(LocalDateTime.now().minusMonths(1).withDayOfMonth(26)))
                .le(ProjectEnum.TProcessesDrilling.DRILLING_DATE.getLabel(), DateUtil.getEndTimeStr(LocalDateTime.now()));

        Double monthDepthSum = baseMapper.getSumByCondition(depth.toString(), queryWrapper);
        return R.ok(new TProcessesProductVo<>(data, depthSum, todayDepthSum, monthDepthSum));
    }

    @Override
    public R insertTProcessesDrilling(TProcessesDrillingQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getStopeName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getStepName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getBlastAreaName());
        Rcode.NOT_PARAM.assertNotEmpty(query.getHoleID());
        //uid自动生成 不能手动设置
        if (query.getUid() != null) {
            return R.failed("uid自动生成 不能手动设置");
        }
        //条件封装
        TProcessesDrilling tProcessesDrilling = new TProcessesDrilling();
        BeanUtils.copyProperties(query, tProcessesDrilling);
        //增加
        int insert = baseMapper.insert(tProcessesDrilling);
        if (insert > 0) {
            return R.ok("增加成功");
        } else {
            log.info(JSON.toJSONString(tProcessesDrilling));
            return R.failed("增加失败");
        }
    }


    @Override
    public R updateByUid(TProcessesDrillingQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //判断数据是否存在
        TProcessesDrilling temp = baseMapper.selectById(query.getUid());
        if (temp == null) {
            return R.failed("数据不存在，uid：" + query.getUid());
        }
        //判断是否需要修改关联的 矿山爆区表
        if (StringUtils.isNotBlank(query.getStepName())
                || StringUtils.isNotBlank(query.getBlastAreaName())
                || StringUtils.isNotBlank(query.getStopeName())) {
            //判断矿山爆区表是否存在数据 不存在不能修改
            //query里不一定StopeName,StepName,BlastAreaName都有，需要从temp中拿query没有的，
            // 所以将query有的更新到temp中，再把temp中的复制到tMineStopeQuery
            BeanUtilsNewCopy.copyPropertiesIgnoreNull(query, temp);
            TMineStopeQuery tMineStopeQuery = new TMineStopeQuery();
            BeanUtils.copyProperties(temp, tMineStopeQuery);
            R volume = itMineStopeService.getByQuery(tMineStopeQuery);
            if (volume.getData() == null) {
                return R.failed("矿山爆区表数据不存在，StopeName,StepName,BlastAreaName");
            }
        }
        //条件封装
        BeanUtilsNewCopy.copyPropertiesIgnoreNull(query, temp);
        //计算单孔爆破量
        //先获取台阶高度
        TProcessesBlastdesignHoleQuery holeQuery = new TProcessesBlastdesignHoleQuery();
        holeQuery.setBlastHoleID(temp.getHoleID());
        R r = itProcessesBlastdesignHoleService.getByBlastHoleID(holeQuery);
        //不为空计算台阶高度
        if (r.getData() != null) {
            TProcessesBlastdesignHole data = (TProcessesBlastdesignHole) r.getData();
            Double volume = calculateHoleBlastVolume(temp.getHoleSpace(), temp.getRowSpace(), data.getStepHeight());
            temp.setHoleBlastVolume(volume);
        }
        QueryWrapper<TProcessesDrilling> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ProjectEnum.TProcessesBlast.UID.getLabel(), query.getUid());
        //修改
        int update = baseMapper.update(temp, queryWrapper);
        if (update > 0) {
            return R.ok("修改成功");
        } else {
            log.info(JSON.toJSONString(temp));
            return R.failed("修改失败");
        }
    }


    @Override
    public R getByUid(TProcessesDrillingQuery query) {
        log.info(JSON.toJSONString(query));
        //参数校验
        Rcode.NOT_PARAM.assertNotNull(query);
        Rcode.NOT_PARAM.assertNotEmpty(query.getUid());
        //查询并且返回
        QueryWrapper<TProcessesDrilling> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ProjectEnum.TProcessesDrilling.UID.getLabel(), query.getUid());
        //查询并且返回
        return R.ok(baseMapper.getByUid(queryWrapper));
    }


    /**
     * 计算并设值 单孔爆破量(m3)=孔距*排距*台阶高度
     */
    private Double calculateHoleBlastVolume(Double HoleSpace, Double RowSpace, Double StepHeight) {
        return HoleSpace * RowSpace * StepHeight;
    }
}
